Class: Google::Shopping::Merchant::Products::V1::HandlingCutoffTime

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

Configuration for offer or offer-country level shipping handling cutoff time.

Instance Attribute Summary collapse

Instance Attribute Details

#country::String

Returns The CLDR territory code of the country to which the handling cutoff time applies.

Returns:

  • (::String)

    The CLDR territory code of the country to which the handling cutoff time applies.



2274
2275
2276
2277
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2274

class HandlingCutoffTime
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cutoff_time::String

Returns The handling cutoff time until which an order has to be placed to be processed in the same day. This is a string in format of HHMM (e.g. 1530) for 3:30 PM. If not configured, the cutoff time will be defaulted to 8AM PST.

Returns:

  • (::String)

    The handling cutoff time until which an order has to be placed to be processed in the same day. This is a string in format of HHMM (e.g. 1530) for 3:30 PM. If not configured, the cutoff time will be defaulted to 8AM PST.



2274
2275
2276
2277
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2274

class HandlingCutoffTime
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cutoff_timezone::String

Returns Timezone identifier For example 'Europe/Zurich'. If not set, the shipping destination timezone will be used.

Returns:

  • (::String)

    Timezone identifier For example 'Europe/Zurich'. If not set, the shipping destination timezone will be used.



2274
2275
2276
2277
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2274

class HandlingCutoffTime
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disable_delivery_after_cutoff::Boolean

Returns This field only applies to same-day delivery. If true, prevents next-day delivery from being shown for this offer after the cutoff time. This field only applies to same-day delivery offers, for merchants who want to explicitly disable it.

Returns:

  • (::Boolean)

    This field only applies to same-day delivery. If true, prevents next-day delivery from being shown for this offer after the cutoff time. This field only applies to same-day delivery offers, for merchants who want to explicitly disable it.



2274
2275
2276
2277
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2274

class HandlingCutoffTime
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end