Class: Google::Shopping::Merchant::Products::V1::ProductDimension

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

The dimension of the product.

Instance Attribute Summary collapse

Instance Attribute Details

#unit::String

Returns Required. The dimension units. Acceptable values are:

* "`in`"
* "`cm`".

Returns:

  • (::String)

    Required. The dimension units. Acceptable values are:

    * "`in`"
    * "`cm`"


2012
2013
2014
2015
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2012

class ProductDimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::Float

Returns Required. The dimension value represented as a number. The value can have a maximum precision of four decimal places.

Returns:

  • (::Float)

    Required. The dimension value represented as a number. The value can have a maximum precision of four decimal places.



2012
2013
2014
2015
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2012

class ProductDimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end