Class: Google::Shopping::Merchant::Products::V1::ProductInstallment
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Products::V1::ProductInstallment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/products/v1/products_common.rb
Overview
A message that represents installment.
Instance Attribute Summary collapse
-
#amount ⇒ ::Google::Shopping::Type::Price
The amount the buyer has to pay per month.
-
#annual_percentage_rate ⇒ ::Float
Optional.
-
#credit_type ⇒ ::Google::Shopping::Merchant::Products::V1::CreditType
Type of installment payments.
-
#downpayment ⇒ ::Google::Shopping::Type::Price
The up-front down payment amount the buyer has to pay.
-
#months ⇒ ::Integer
The number of installments the buyer has to pay.
-
#total_amount ⇒ ::Google::Shopping::Type::Price
Optional.
Instance Attribute Details
#amount ⇒ ::Google::Shopping::Type::Price
Returns The amount the buyer has to pay per month.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#annual_percentage_rate ⇒ ::Float
Returns Optional. Annual percentage rate for credit_type finance.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#credit_type ⇒ ::Google::Shopping::Merchant::Products::V1::CreditType
Returns Type of installment payments.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#downpayment ⇒ ::Google::Shopping::Type::Price
Returns The up-front down payment amount the buyer has to pay.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#months ⇒ ::Integer
Returns The number of installments the buyer has to pay.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_amount ⇒ ::Google::Shopping::Type::Price
Returns Optional. Total amount the buyer has to pay, including interest.
1741 1742 1743 1744 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1741 class ProductInstallment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |