Class: Google::Shopping::Merchant::Products::V1::ProductStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

The status of a product, data validation issues, that is, information about a product computed asynchronously.

Defined Under Namespace

Classes: DestinationStatus, ItemLevelIssue

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date::Google::Protobuf::Timestamp

Returns Date on which the item has been created, in ISO 8601 format.

Returns:



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2055

class ProductStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination status of the product status.
  #
  # Equivalent to
  # [`StatusPerReportingContext`][google.shopping.merchant.reports.v1.ProductView.StatusPerReportingContext]
  # in Reports API.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The name of the reporting context.
  # @!attribute [rw] approved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
  # @!attribute [rw] pending_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is pending
  #     approval.
  # @!attribute [rw] disapproved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is
  #     disapproved.
  class DestinationStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The ItemLevelIssue of the product status.
  # @!attribute [rw] code
  #   @return [::String]
  #     The error code of the issue.
  # @!attribute [rw] severity
  #   @return [::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue::Severity]
  #     How this issue affects serving of the offer.
  # @!attribute [rw] resolution
  #   @return [::String]
  #     Whether the issue can be resolved by the business.
  # @!attribute [rw] attribute
  #   @return [::String]
  #     The attribute's name, if the issue is caused by a single attribute.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The reporting context the issue applies to.
  # @!attribute [rw] description
  #   @return [::String]
  #     A short issue description in English.
  # @!attribute [rw] detail
  #   @return [::String]
  #     A detailed issue description in English.
  # @!attribute [rw] documentation
  #   @return [::String]
  #     The URL of a web page to help with resolving this issue.
  # @!attribute [rw] applicable_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where issue applies to the
  #     offer.
  class ItemLevelIssue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # How the issue affects the serving of the product.
    module Severity
      # Not specified.
      SEVERITY_UNSPECIFIED = 0

      # This issue represents a warning and does not have a direct affect
      # on the product.
      NOT_IMPACTED = 1

      # The product is demoted and most likely have limited performance
      # in search results
      DEMOTED = 2

      # Issue disapproves the product.
      DISAPPROVED = 3
    end
  end
end

#destination_statuses::Array<::Google::Shopping::Merchant::Products::V1::ProductStatus::DestinationStatus>

Returns The intended destinations for the product.

Returns:



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2055

class ProductStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination status of the product status.
  #
  # Equivalent to
  # [`StatusPerReportingContext`][google.shopping.merchant.reports.v1.ProductView.StatusPerReportingContext]
  # in Reports API.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The name of the reporting context.
  # @!attribute [rw] approved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
  # @!attribute [rw] pending_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is pending
  #     approval.
  # @!attribute [rw] disapproved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is
  #     disapproved.
  class DestinationStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The ItemLevelIssue of the product status.
  # @!attribute [rw] code
  #   @return [::String]
  #     The error code of the issue.
  # @!attribute [rw] severity
  #   @return [::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue::Severity]
  #     How this issue affects serving of the offer.
  # @!attribute [rw] resolution
  #   @return [::String]
  #     Whether the issue can be resolved by the business.
  # @!attribute [rw] attribute
  #   @return [::String]
  #     The attribute's name, if the issue is caused by a single attribute.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The reporting context the issue applies to.
  # @!attribute [rw] description
  #   @return [::String]
  #     A short issue description in English.
  # @!attribute [rw] detail
  #   @return [::String]
  #     A detailed issue description in English.
  # @!attribute [rw] documentation
  #   @return [::String]
  #     The URL of a web page to help with resolving this issue.
  # @!attribute [rw] applicable_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where issue applies to the
  #     offer.
  class ItemLevelIssue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # How the issue affects the serving of the product.
    module Severity
      # Not specified.
      SEVERITY_UNSPECIFIED = 0

      # This issue represents a warning and does not have a direct affect
      # on the product.
      NOT_IMPACTED = 1

      # The product is demoted and most likely have limited performance
      # in search results
      DEMOTED = 2

      # Issue disapproves the product.
      DISAPPROVED = 3
    end
  end
end

#google_expiration_date::Google::Protobuf::Timestamp

Returns Date on which the item expires, in ISO 8601 format.

Returns:



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2055

class ProductStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination status of the product status.
  #
  # Equivalent to
  # [`StatusPerReportingContext`][google.shopping.merchant.reports.v1.ProductView.StatusPerReportingContext]
  # in Reports API.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The name of the reporting context.
  # @!attribute [rw] approved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
  # @!attribute [rw] pending_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is pending
  #     approval.
  # @!attribute [rw] disapproved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is
  #     disapproved.
  class DestinationStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The ItemLevelIssue of the product status.
  # @!attribute [rw] code
  #   @return [::String]
  #     The error code of the issue.
  # @!attribute [rw] severity
  #   @return [::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue::Severity]
  #     How this issue affects serving of the offer.
  # @!attribute [rw] resolution
  #   @return [::String]
  #     Whether the issue can be resolved by the business.
  # @!attribute [rw] attribute
  #   @return [::String]
  #     The attribute's name, if the issue is caused by a single attribute.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The reporting context the issue applies to.
  # @!attribute [rw] description
  #   @return [::String]
  #     A short issue description in English.
  # @!attribute [rw] detail
  #   @return [::String]
  #     A detailed issue description in English.
  # @!attribute [rw] documentation
  #   @return [::String]
  #     The URL of a web page to help with resolving this issue.
  # @!attribute [rw] applicable_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where issue applies to the
  #     offer.
  class ItemLevelIssue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # How the issue affects the serving of the product.
    module Severity
      # Not specified.
      SEVERITY_UNSPECIFIED = 0

      # This issue represents a warning and does not have a direct affect
      # on the product.
      NOT_IMPACTED = 1

      # The product is demoted and most likely have limited performance
      # in search results
      DEMOTED = 2

      # Issue disapproves the product.
      DISAPPROVED = 3
    end
  end
end

#item_level_issues::Array<::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue>

Returns A list of all issues associated with the product.

Returns:



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2055

class ProductStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination status of the product status.
  #
  # Equivalent to
  # [`StatusPerReportingContext`][google.shopping.merchant.reports.v1.ProductView.StatusPerReportingContext]
  # in Reports API.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The name of the reporting context.
  # @!attribute [rw] approved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
  # @!attribute [rw] pending_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is pending
  #     approval.
  # @!attribute [rw] disapproved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is
  #     disapproved.
  class DestinationStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The ItemLevelIssue of the product status.
  # @!attribute [rw] code
  #   @return [::String]
  #     The error code of the issue.
  # @!attribute [rw] severity
  #   @return [::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue::Severity]
  #     How this issue affects serving of the offer.
  # @!attribute [rw] resolution
  #   @return [::String]
  #     Whether the issue can be resolved by the business.
  # @!attribute [rw] attribute
  #   @return [::String]
  #     The attribute's name, if the issue is caused by a single attribute.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The reporting context the issue applies to.
  # @!attribute [rw] description
  #   @return [::String]
  #     A short issue description in English.
  # @!attribute [rw] detail
  #   @return [::String]
  #     A detailed issue description in English.
  # @!attribute [rw] documentation
  #   @return [::String]
  #     The URL of a web page to help with resolving this issue.
  # @!attribute [rw] applicable_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where issue applies to the
  #     offer.
  class ItemLevelIssue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # How the issue affects the serving of the product.
    module Severity
      # Not specified.
      SEVERITY_UNSPECIFIED = 0

      # This issue represents a warning and does not have a direct affect
      # on the product.
      NOT_IMPACTED = 1

      # The product is demoted and most likely have limited performance
      # in search results
      DEMOTED = 2

      # Issue disapproves the product.
      DISAPPROVED = 3
    end
  end
end

#last_update_date::Google::Protobuf::Timestamp

Returns Date on which the item has been last updated, in ISO 8601 format.

Returns:



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2055

class ProductStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination status of the product status.
  #
  # Equivalent to
  # [`StatusPerReportingContext`][google.shopping.merchant.reports.v1.ProductView.StatusPerReportingContext]
  # in Reports API.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The name of the reporting context.
  # @!attribute [rw] approved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
  # @!attribute [rw] pending_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is pending
  #     approval.
  # @!attribute [rw] disapproved_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where the offer is
  #     disapproved.
  class DestinationStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The ItemLevelIssue of the product status.
  # @!attribute [rw] code
  #   @return [::String]
  #     The error code of the issue.
  # @!attribute [rw] severity
  #   @return [::Google::Shopping::Merchant::Products::V1::ProductStatus::ItemLevelIssue::Severity]
  #     How this issue affects serving of the offer.
  # @!attribute [rw] resolution
  #   @return [::String]
  #     Whether the issue can be resolved by the business.
  # @!attribute [rw] attribute
  #   @return [::String]
  #     The attribute's name, if the issue is caused by a single attribute.
  # @!attribute [rw] reporting_context
  #   @return [::Google::Shopping::Type::ReportingContext::ReportingContextEnum]
  #     The reporting context the issue applies to.
  # @!attribute [rw] description
  #   @return [::String]
  #     A short issue description in English.
  # @!attribute [rw] detail
  #   @return [::String]
  #     A detailed issue description in English.
  # @!attribute [rw] documentation
  #   @return [::String]
  #     The URL of a web page to help with resolving this issue.
  # @!attribute [rw] applicable_countries
  #   @return [::Array<::String>]
  #     List of country codes (ISO 3166-1 alpha-2) where issue applies to the
  #     offer.
  class ItemLevelIssue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # How the issue affects the serving of the product.
    module Severity
      # Not specified.
      SEVERITY_UNSPECIFIED = 0

      # This issue represents a warning and does not have a direct affect
      # on the product.
      NOT_IMPACTED = 1

      # The product is demoted and most likely have limited performance
      # in search results
      DEMOTED = 2

      # Issue disapproves the product.
      DISAPPROVED = 3
    end
  end
end