Class: Google::Shopping::Merchant::Products::V1::ProductSustainabilityIncentive

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

Information regarding sustainability-related incentive programs such as rebates or tax relief.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#amount::Google::Shopping::Type::Price

Returns The fixed amount of the incentive.

Note: The following fields are mutually exclusive: amount, percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Shopping::Type::Price)

    The fixed amount of the incentive.

    Note: The following fields are mutually exclusive: amount, percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.



2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2195

class ProductSustainabilityIncentive
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of supported sustainability incentive programs.
  module Type
    # Unspecified or unknown sustainability incentive type.
    TYPE_UNSPECIFIED = 0

    # Program offering tax liability reductions for electric vehicles and, in
    # some countries, plug-in hybrids. These reductions can be based on a
    # specific amount or a percentage of the sale price.
    EV_TAX_CREDIT = 1

    # A subsidy program, often called an environmental bonus, provides a
    # purchase grant for electric vehicles and, in some countries, plug-in
    # hybrids. The grant amount may be a fixed sum or a percentage of the sale
    # price.
    EV_PRICE_DISCOUNT = 2
  end
end

#percentage::Float

Returns The percentage of the sale price that the incentive is applied to.

Note: The following fields are mutually exclusive: percentage, amount. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    The percentage of the sale price that the incentive is applied to.

    Note: The following fields are mutually exclusive: percentage, amount. If a field in that set is populated, all other fields in the set will automatically be cleared.



2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2195

class ProductSustainabilityIncentive
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of supported sustainability incentive programs.
  module Type
    # Unspecified or unknown sustainability incentive type.
    TYPE_UNSPECIFIED = 0

    # Program offering tax liability reductions for electric vehicles and, in
    # some countries, plug-in hybrids. These reductions can be based on a
    # specific amount or a percentage of the sale price.
    EV_TAX_CREDIT = 1

    # A subsidy program, often called an environmental bonus, provides a
    # purchase grant for electric vehicles and, in some countries, plug-in
    # hybrids. The grant amount may be a fixed sum or a percentage of the sale
    # price.
    EV_PRICE_DISCOUNT = 2
  end
end

#type::Google::Shopping::Merchant::Products::V1::ProductSustainabilityIncentive::Type

Returns Sustainability incentive program.



2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2195

class ProductSustainabilityIncentive
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of supported sustainability incentive programs.
  module Type
    # Unspecified or unknown sustainability incentive type.
    TYPE_UNSPECIFIED = 0

    # Program offering tax liability reductions for electric vehicles and, in
    # some countries, plug-in hybrids. These reductions can be based on a
    # specific amount or a percentage of the sale price.
    EV_TAX_CREDIT = 1

    # A subsidy program, often called an environmental bonus, provides a
    # purchase grant for electric vehicles and, in some countries, plug-in
    # hybrids. The grant amount may be a fixed sum or a percentage of the sale
    # price.
    EV_PRICE_DISCOUNT = 2
  end
end