Class: Google::Shopping::Merchant::Products::V1::ProductWeight

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

The weight of the product.

Instance Attribute Summary collapse

Instance Attribute Details

#unit::String

Returns Required. The weight unit. Acceptable values are:

* "`g`"
* "`kg`"
* "`oz`"
* "`lb`".

Returns:

  • (::String)

    Required. The weight unit. Acceptable values are:

    * "`g`"
    * "`kg`"
    * "`oz`"
    * "`lb`"


2030
2031
2032
2033
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2030

class ProductWeight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::Float

Returns Required. The weight represented as a number. The weight can have a maximum precision of four decimal places.

Returns:

  • (::Float)

    Required. The weight represented as a number. The weight can have a maximum precision of four decimal places.



2030
2031
2032
2033
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2030

class ProductWeight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end