Class: Google::Shopping::Merchant::Products::V1::Shipping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

The Shipping of the product.

Instance Attribute Summary collapse

Instance Attribute Details

#country::String

Returns The CLDR territory code of the country to which an item will ship.

Returns:



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#handling_cutoff_time::String

Returns The handling cutoff time until which an order has to be placed to be processed in the same day. This is a string in format of HHMM (e.g. 1530) for 3:30 PM. If not configured, the cutoff time will be defaulted to 8AM PST and handling_cutoff_timezone will be ignored.

Returns:

  • (::String)

    The handling cutoff time until which an order has to be placed to be processed in the same day. This is a string in format of HHMM (e.g. 1530) for 3:30 PM. If not configured, the cutoff time will be defaulted to 8AM PST and handling_cutoff_timezone will be ignored.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#handling_cutoff_timezone::String

Returns Timezone identifier For example Europe/Zurich. This field only applies if handling_cutoff_time is set. If handling_cutoff_time is set but this field is not set, the shipping destination timezone will be used. If both fields are not set, the handling cutoff time will default to 8AM PST.

Returns:

  • (::String)

    Timezone identifier For example Europe/Zurich. This field only applies if handling_cutoff_time is set. If handling_cutoff_time is set but this field is not set, the shipping destination timezone will be used. If both fields are not set, the handling cutoff time will default to 8AM PST.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location_group_name::String

Returns The location where the shipping is applicable, represented by a location group name.

Returns:

  • (::String)

    The location where the shipping is applicable, represented by a location group name.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location_id::Integer

Returns The numeric ID of a location that the shipping rate applies to as defined in the AdWords API.

Returns:

  • (::Integer)

    The numeric ID of a location that the shipping rate applies to as defined in the AdWords API.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#loyalty_program_label::String

Returns Optional. The label of the loyalty program. Must match one of the program labels set in loyalty_programs. When set (in combination with loyalty_tier_label), this shipping option is only applicable to loyalty program members of the specified tier.

Returns:

  • (::String)

    Optional. The label of the loyalty program. Must match one of the program labels set in loyalty_programs. When set (in combination with loyalty_tier_label), this shipping option is only applicable to loyalty program members of the specified tier.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#loyalty_tier_label::String

Returns Optional. The label of the loyalty tier within the loyalty program. Must match one of the tiers set in the loyalty_programs. When set (in combination with loyalty_program_label), this shipping option is only applicable to loyalty program members of the specified tier.

Returns:

  • (::String)

    Optional. The label of the loyalty tier within the loyalty program. Must match one of the tiers set in the loyalty_programs. When set (in combination with loyalty_program_label), this shipping option is only applicable to loyalty program members of the specified tier.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_handling_time::Integer

Returns Maximum handling time (inclusive) between when the order is received and shipped in business days. 0 means that the order is shipped on the same day as it is received if it happens before the cut-off time. Both maxHandlingTime and maxTransitTime are required if providing shipping speeds. minHandlingTime is optional if maxHandlingTime is present.

Returns:

  • (::Integer)

    Maximum handling time (inclusive) between when the order is received and shipped in business days. 0 means that the order is shipped on the same day as it is received if it happens before the cut-off time. Both maxHandlingTime and maxTransitTime are required if providing shipping speeds. minHandlingTime is optional if maxHandlingTime is present.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_transit_time::Integer

Returns Maximum transit time (inclusive) between when the order has shipped and when it is delivered in business days. 0 means that the order is delivered on the same day as it ships. Both maxHandlingTime and maxTransitTime are required if providing shipping speeds. minTransitTime is optional if maxTransitTime is present.

Returns:

  • (::Integer)

    Maximum transit time (inclusive) between when the order has shipped and when it is delivered in business days. 0 means that the order is delivered on the same day as it ships. Both maxHandlingTime and maxTransitTime are required if providing shipping speeds. minTransitTime is optional if maxTransitTime is present.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_handling_time::Integer

Returns Minimum handling time (inclusive) between when the order is received and shipped in business days. 0 means that the order is shipped on the same day as it is received if it happens before the cut-off time. minHandlingTime can only be present together with maxHandlingTime; but it is not required if maxHandlingTime is present.

Returns:

  • (::Integer)

    Minimum handling time (inclusive) between when the order is received and shipped in business days. 0 means that the order is shipped on the same day as it is received if it happens before the cut-off time. minHandlingTime can only be present together with maxHandlingTime; but it is not required if maxHandlingTime is present.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_transit_time::Integer

Returns Minimum transit time (inclusive) between when the order has shipped and when it is delivered in business days. 0 means that the order is delivered on the same day as it ships. minTransitTime can only be present together with maxTransitTime; but it is not required if maxTransitTime is present.

Returns:

  • (::Integer)

    Minimum transit time (inclusive) between when the order has shipped and when it is delivered in business days. 0 means that the order is delivered on the same day as it ships. minTransitTime can only be present together with maxTransitTime; but it is not required if maxTransitTime is present.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#postal_code::String

Returns The postal code range that the shipping rate applies to, represented by a postal code, a postal code prefix followed by a * wildcard, a range between two postal codes or two postal code prefixes of equal length.

Returns:

  • (::String)

    The postal code range that the shipping rate applies to, represented by a postal code, a postal code prefix followed by a * wildcard, a range between two postal codes or two postal code prefixes of equal length.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#price::Google::Shopping::Type::Price

Returns Fixed shipping price, represented as a number.

Returns:



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns The geographic region to which a shipping rate applies. See region for more information.

Returns:

  • (::String)

    The geographic region to which a shipping rate applies. See region for more information.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service::String

Returns A free-form description of the service class or delivery speed.

Returns:

  • (::String)

    A free-form description of the service class or delivery speed.



1915
1916
1917
1918
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1915

class Shipping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end