Class: Google::Shopping::Merchant::Products::V1::SubscriptionCost

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1/products_common.rb

Overview

The SubscriptionCost of the product.

Instance Attribute Summary collapse

Instance Attribute Details

#amount::Google::Shopping::Type::Price

Returns The amount the buyer has to pay per subscription period.

Returns:



1717
1718
1719
1720
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1717

class SubscriptionCost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#period::Google::Shopping::Merchant::Products::V1::SubscriptionPeriod

Returns The type of subscription period. Supported values are:

* "`month`"
* "`year`"
* "`week`".

Returns:



1717
1718
1719
1720
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1717

class SubscriptionCost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#period_length::Integer

Returns The number of subscription periods the buyer has to pay.

Returns:

  • (::Integer)

    The number of subscription periods the buyer has to pay.



1717
1718
1719
1720
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 1717

class SubscriptionCost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end