Class: Google::Shopping::Merchant::Products::V1::DeleteProductInputRequest
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Products::V1::DeleteProductInputRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/products/v1/productinputs.rb
Overview
Request message for the DeleteProductInput method.
Instance Attribute Summary collapse
-
#data_source ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#data_source ⇒ ::String
Returns Required. The primary or supplemental data source from which the product
input should be deleted. Format:
accounts/{account}/dataSources/{datasource}. For example,
accounts/123456/dataSources/104628.
289 290 291 292 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 289 class DeleteProductInputRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the product input to delete.
Format: accounts/{account}/productInputs/{productInput}
The {productInput} segment is a unique identifier for the product.
This identifier must be unique within a merchant account and generally
follows the structure: content_language~feed_label~offer_id. Example:
en~US~sku123 For legacy local products, the structure is:
local~content_language~feed_label~offer_id. Example: local~en~US~sku123
The format of the {productInput} segment in the URL is automatically detected by the server, supporting two options:
-
Encoded Format: The
{productInput}segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in thecontent_language~feed_label~offer_idstructure. This encoding MUST be used if any part of the product identifier (likeoffer_id) contains characters such as/,%, or~.- Example: To represent the product ID
en~US~sku/123, the{productInput}segment must be the unpadded base64url encoding of this string, which isZW5-VVN-c2t1LzEyMw. The full resource name for the product would beaccounts/123/productInputs/ZW5-VVN-c2t1LzEyMw.
- Example: To represent the product ID
-
Plain Format: The
{productInput}segment is the tilde-separated stringcontent_language~feed_label~offer_id. This format is suitable only whencontent_language,feed_label, andoffer_iddo not contain URL-problematic characters like/,%, or~.
We recommend using the Encoded Format for all product IDs to ensure
correct parsing, especially those containing special characters. The
presence of tilde (~) characters in the {productInput} segment is used
to differentiate between the two formats.
289 290 291 292 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 289 class DeleteProductInputRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |