Class: Google::Shopping::Merchant::Products::V1::ProductInput
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Products::V1::ProductInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/products/v1/productinputs.rb
Overview
This resource represents input data you submit for a product, not the processed product that you see in Merchant Center, in Shopping ads, or across Google surfaces. Product inputs, rules and supplemental data source data are combined to create the processed Product. For more information, see Manage products.
Required product input attributes to pass data validation checks are primarily defined in the Products Data Specification.
The following attributes are required: feedLabel, contentLanguage and offerId.
After inserting, updating, or deleting a product input, it may take several minutes before the processed product can be retrieved.
All fields in the product input and its sub-messages match the English name of their corresponding attribute in the Products Data Specification with some exceptions. The following reference documentation lists the field names in the camelCase casing style while the Products Data Specification lists the names in the snake_case casing style.
Instance Attribute Summary collapse
-
#base64_encoded_name ⇒ ::String
readonly
Output only.
-
#base64_encoded_product ⇒ ::String
readonly
Output only.
-
#content_language ⇒ ::String
Required.
-
#custom_attributes ⇒ ::Array<::Google::Shopping::Type::CustomAttribute>
Optional.
-
#feed_label ⇒ ::String
Required.
-
#legacy_local ⇒ ::Boolean
Immutable.
-
#name ⇒ ::String
Identifier.
-
#offer_id ⇒ ::String
Required.
-
#product ⇒ ::String
readonly
Output only.
-
#product_attributes ⇒ ::Google::Shopping::Merchant::Products::V1::ProductAttributes
Optional.
-
#version_number ⇒ ::Integer
Optional.
Instance Attribute Details
#base64_encoded_name ⇒ ::String (readonly)
Returns Output only. The unpadded base64url encoded name of the product input.
Format:
accounts/{account}/productInputs/{productinput} where the last
section productinput is the unpadded base64url encoding of the
content_language~feed_label~offer_id name.
Example: accounts/123/productInputs/ZW5-VVN-c2t1LzEyMw for the decoded
product input name accounts/123/productInputs/en~US~sku/123. This field
can be used directly as input to the API methods that require the product
input name to be encoded if it contains special characters, for example
GetProductInput.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#base64_encoded_product ⇒ ::String (readonly)
Returns Output only. The unpadded base64url encoded name of the processed
product. Format: accounts/{account}/products/{product} where the last
section product is the unpadded base64url encoding of the
content_language~feed_label~offer_id name.
Example: accounts/123/products/ZW5-VVN-c2t1LzEyMw for the decoded
product name accounts/123/products/en~US~sku/123. This field can be used
directly as input to the API methods that require the product name to be
encoded if it contains special characters, for example
GetProduct.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#content_language ⇒ ::String
Returns Required. Immutable. The two-letter ISO 639-1 language code for the product.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_attributes ⇒ ::Array<::Google::Shopping::Type::CustomAttribute>
Returns Optional. A list of custom (merchant-provided) attributes. It can also be
used for submitting any attribute of the data specification in its generic
form (for example,
{ "name": "size type", "value": "regular" }).
This is useful for submitting attributes not explicitly exposed by the
API.
Maximum allowed number of characters for each
custom attribute is 10240 (represents sum of characters for name and
value). Maximum 2500 custom attributes can be set per product, with total
size of 102.4kB. Underscores in custom attribute names are replaced by
spaces upon insertion.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#feed_label ⇒ ::String
Returns Required. Immutable. The feed label that lets you categorize and identify
your products. The maximum allowed characters are 20, and the supported
characters are A-Z, 0-9, hyphen, and underscore. The feed label must
not include any spaces. For more information, see Using feed
labels.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#legacy_local ⇒ ::Boolean
Returns Immutable. Determines whether the product is only targeting
local destinations and whether the product name should be distinguished
with a local~ prefix. For example,
accounts/123/productInputs/local~en~US~sku123. If a product that is not
legacy_local is already targeting local destinations,
creating a legacy_local product with an otherwise matching name will
fail.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the product.
Format: accounts/{account}/productInputs/{productinput}
The {productinput} segment is a unique identifier for the product.
This identifier must be unique within a merchant account and generally
follows the structure: content_language~feed_label~offer_id. Example:
en~US~sku123 For legacy local products, the structure is:
local~content_language~feed_label~offer_id. Example: local~en~US~sku123
The format of the {productinput} segment in the URL is automatically detected by the server, supporting two options:
Encoded Format: The
{productinput}segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in thecontent_language~feed_label~offer_idstructure. This encoding MUST be used if any part of the product identifier (likeoffer_id) contains characters such as/,%, or~.- Example: To represent the product ID
en~US~sku/123, the{productinput}segment must be the unpadded base64url encoding of this string, which isZW5-VVN-c2t1LzEyMw. The full resource name for the product would beaccounts/123/productInputs/ZW5-VVN-c2t1LzEyMw.
- Example: To represent the product ID
Plain Format: The
{productinput}segment is the tilde-separated stringcontent_language~feed_label~offer_id. This format is suitable only whencontent_language,feed_label, andoffer_iddo not contain URL-problematic characters like/,%, or~.
We recommend using the Encoded Format for all product IDs to ensure
correct parsing, especially those containing special characters. The
presence of tilde (~) characters in the {productinput} segment is used
to differentiate between the two formats.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#offer_id ⇒ ::String
Returns Required. Immutable. Your unique identifier for the product. This is the same for the product input and processed product. Leading and trailing whitespaces are stripped and multiple whitespaces are replaced by a single whitespace upon submission. See the products data specification for details.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product ⇒ ::String (readonly)
Returns Output only. The name of the processed product.
Format: accounts/{account}/products/{product}.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_attributes ⇒ ::Google::Shopping::Merchant::Products::V1::ProductAttributes
Returns Optional. A list of strongly-typed product attributes.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version_number ⇒ ::Integer
Returns Optional. Immutable. Represents the existing version (freshness) of the product, which can be used to preserve the right order when multiple updates are done at the same time.
If set, the insertion is prevented when version number is lower than
the current version number of the existing product. Re-insertion (for
example, product refresh after 30 days) can be performed with the current
version_number.
Only supported for insertions into primary data sources. Do not set this field for updates. Do not set this field for insertions into supplemental data sources.
If the operation is prevented, the aborted exception will be thrown.
176 177 178 179 |
# File 'proto_docs/google/shopping/merchant/products/v1/productinputs.rb', line 176 class ProductInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |