Class: Google::Shopping::Merchant::Products::V1::ProductMinimumOrderValue
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Products::V1::ProductMinimumOrderValue
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/products/v1/products_common.rb
Overview
The minimum order value in the cart before the checkout is permitted.
Defined Under Namespace
Modules: Surface
Instance Attribute Summary collapse
-
#country ⇒ ::String
Required.
-
#price ⇒ ::Google::Shopping::Type::Price
Required.
-
#service ⇒ ::String
A free-form description of the service class or delivery speed.
-
#surface ⇒ ::Google::Shopping::Merchant::Products::V1::ProductMinimumOrderValue::Surface
The surface to which the minimum order value applies.
Instance Attribute Details
#country ⇒ ::String
Returns Required. The CLDR territory code of the country to which an item will ship.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2298 class ProductMinimumOrderValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The surface values to which the minimum order value applies. module Surface # Surface is unspecified. SURFACE_UNSPECIFIED = 0 # Surface value to indicate online purchases. ONLINE = 1 # Surface value to indicate local purchases. LOCAL = 2 # Surface value to indicate online and local purchases. ONLINE_LOCAL = 3 end end |
#price ⇒ ::Google::Shopping::Type::Price
Returns Required. The minimum cart or basket value before the checkout is permitted.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2298 class ProductMinimumOrderValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The surface values to which the minimum order value applies. module Surface # Surface is unspecified. SURFACE_UNSPECIFIED = 0 # Surface value to indicate online purchases. ONLINE = 1 # Surface value to indicate local purchases. LOCAL = 2 # Surface value to indicate online and local purchases. ONLINE_LOCAL = 3 end end |
#service ⇒ ::String
Returns A free-form description of the service class or delivery speed. This should match the service value set for the Shipping attribute. See service.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2298 class ProductMinimumOrderValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The surface values to which the minimum order value applies. module Surface # Surface is unspecified. SURFACE_UNSPECIFIED = 0 # Surface value to indicate online purchases. ONLINE = 1 # Surface value to indicate local purchases. LOCAL = 2 # Surface value to indicate online and local purchases. ONLINE_LOCAL = 3 end end |
#surface ⇒ ::Google::Shopping::Merchant::Products::V1::ProductMinimumOrderValue::Surface
Returns The surface to which the minimum order value applies.
Defaults to ONLINE_LOCAL if not configured.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 |
# File 'proto_docs/google/shopping/merchant/products/v1/products_common.rb', line 2298 class ProductMinimumOrderValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The surface values to which the minimum order value applies. module Surface # Surface is unspecified. SURFACE_UNSPECIFIED = 0 # Surface value to indicate online purchases. ONLINE = 1 # Surface value to indicate local purchases. LOCAL = 2 # Surface value to indicate online and local purchases. ONLINE_LOCAL = 3 end end |